@@ -7,7 +7,7 @@ use Class::Accessor::Lite;
 use Time::List::Rows::Row;
 use Time::List::Constant;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 my $unit_time = {
     DAY()   => 3600 * 24 , 
@@ -146,7 +146,7 @@ sub get_array{
             my $row = $unixtime_rows_hash->{$_->unixtime}->get_values;
             for my $key(keys %$row){
                 my $value = $row->{$key};
-                if($value && $value =~ /^\d+$/){
+                if($value && $value =~ /(^|^-)(\d+|\d+\.\d+)$/){
                     $summary->{$key} += $value;
                 }
             }
@@ -178,7 +178,7 @@ Time::List::Rows - Perl extention to output time list
 
 =head1 VERSION
 
-This document describes Time::List::Rows version 0.10.
+This document describes Time::List::Rows version 0.11.
 
 =head1 SYNOPSIS
 
